import {
  customElement,
  type TemplateResult,
  state,
  html,
  property,
  css,
  cssManager,
} from '@design.estate/dees-element';
import * as domtools from '@design.estate/dees-domtools';
import { DeesInputBase } from './dees-input-base.js';

const { demoFunc } = await import('./dees-input-typelist.demo.js');

@customElement('dees-input-typelist')
export class DeesInputTypelist extends DeesInputBase<DeesInputTypelist> {
  public static demo = demoFunc;


  // INSTANCE

  @property({ type: Array })
  public value: string[] = [];

  @state()
  private inputValue: string = '';


  public static styles = [
    ...DeesInputBase.baseStyles,
    cssManager.defaultStyles,
    css`
      :host {
        color: ${cssManager.bdTheme('#333', '#fff')};
      }
      .mainbox {
        border-radius: 3px;
        background: #222;
        overflow: hidden;
        border-top: ${cssManager.bdTheme('1px solid #CCC', '1px solid #444')};
        border-bottom: ${cssManager.bdTheme('1px solid #CCC', '1px solid #333')};
        border-right: ${cssManager.bdTheme('1px solid #CCC', 'none')};
        border-left: ${cssManager.bdTheme('1px solid #CCC', 'none')};
      }

      .tags {
        padding: 16px;
        cursor: default;
      }

      .notags {
        text-align: center;
        opacity: 0.5;
        font-size: 12px;
      }

      input {
        display: block;
        box-sizing: border-box;
        background: #181818;
        width: 100%;
        outline: none;
        border: none;
        color: inherit;
        padding: 0px 16px;
        overflow: hidden;
        line-height: 32px;
        height: 0px;
        transition: height 0.2s;
      }

      input:focus {
        height: 32px;
      }

      .tag {
        display: inline-block;
        background: ${cssManager.bdTheme('#e0e0e0', '#444')};
        color: ${cssManager.bdTheme('#333', '#fff')};
        padding: 4px 8px;
        border-radius: 3px;
        margin: 2px;
        font-size: 12px;
      }

      .tag .remove {
        margin-left: 6px;
        cursor: pointer;
        opacity: 0.6;
      }

      .tag .remove:hover {
        opacity: 1;
      }
    `,
  ];

  public render(): TemplateResult {
    return html`
      <div class="input-wrapper">
        <dees-label .label=${this.label} .description=${this.description}></dees-label>
        <div class="mainbox">
          <div class="tags" @click=${() => {
            this.shadowRoot.querySelector('input').focus();
          }}>
            ${this.value.length === 0
              ? html`<div class="notags">No tags yet</div>`
              : this.value.map(
                  (tag) => html`
                    <span class="tag">
                      ${tag}
                      <span class="remove" @click=${(e: Event) => {
                        e.stopPropagation();
                        this.removeTag(tag);
                      }}>×</span>
                    </span>
                  `
                )}
          </div>
          <input
            type="text"
            placeholder="Type, press Enter to add it..."
            .value=${this.inputValue}
            @input=${(e: InputEvent) => {
              this.inputValue = (e.target as HTMLInputElement).value;
            }}
            @keydown=${(e: KeyboardEvent) => {
              if (e.key === 'Enter' && this.inputValue.trim()) {
                e.preventDefault();
                this.addTag(this.inputValue.trim());
              }
            }}
            .disabled=${this.disabled}
          />
        </div>
      </div>
    `;
  }

  private addTag(tag: string) {
    if (!this.value.includes(tag)) {
      this.value = [...this.value, tag];
      this.inputValue = '';
      this.changeSubject.next(this);
    }
  }

  private removeTag(tag: string) {
    this.value = this.value.filter((t) => t !== tag);
    this.changeSubject.next(this);
  }

  public getValue(): string[] {
    return this.value;
  }

  public setValue(value: string[]): void {
    this.value = value;
  }
}
